Get Landpred Model
get_model.RdFits the base GLM (no short covariate info) and creates a landpred model object.
Creates a landpred model object for a specific landmark time and prediction window. Dispatches to continuous or discrete model creation based on the landpred object type.
Usage
get_model(landpred_obj, t0, tau, bw = NULL, transform = identity)
get_model(landpred_obj, t0, tau, bw = NULL, transform = identity)